==========================
 ``zope.contentprovider``
==========================

.. image:: https://img.shields.io/pypi/v/zope.contentprovider.svg
        :target: https://pypi.python.org/pypi/zope.contentprovider/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.contentprovider.svg
        :target: https://pypi.org/project/zope.contentprovider/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.contentprovider.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.contentprovider

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.contentprovider/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.contentprovider?branch=master

This package provides a framework to develop componentized Web GUI
applications. Instead of describing the content of a page using a single
template or static system of templates and METAL macros, content provider
objects are dynamically looked up based on the setup/configuration of the
application.
